@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: liblwgeom.h.in 11409 2013-05-10 17:17:18Z colivier $
+ * $Id: liblwgeom.h.in 13391 2015-03-23 16:34:30Z strk $
  *
  * PostGIS - Spatial Types for PostgreSQL
  *
@@ -40,10 +40,10 @@
 /**
  * liblwgeom versions
  */
-#define LIBLWGEOM_VERSION "2.1.0"
+#define LIBLWGEOM_VERSION "2.1.8"
 #define LIBLWGEOM_VERSION_MAJOR "2"
 #define LIBLWGEOM_VERSION_MINOR "1"
-#define LIBLWGEOM_GEOS_VERSION "33"
+#define LIBLWGEOM_GEOS_VERSION "34"
 
 /**
 * Return types for functions with status returns.
@@ -600,6 +600,12 @@ extern uint8_t gflags(int hasz, int hasm, int geodetic);
 */
 extern uint32_t gserialized_get_type(const GSERIALIZED *g);
 
+/** 
+* Returns the size in bytes to read from toast to get the basic 
+* information from a geometry: GSERIALIZED struct, bbox and type 
+*/
+extern uint32_t gserialized_max_header_size(void);
+
 /**
 * Extract the SRID from the serialized form (it is packed into
 * three bytes so this is a handy function).
@@ -635,6 +641,11 @@ extern int gserialized_has_z(const GSERIALIZED *gser);
 */
 extern int gserialized_has_m(const GSERIALIZED *gser);
 
+/**
+* Check if a #GSERIALIZED is a geography.
+*/
+extern int gserialized_is_geodetic(const GSERIALIZED *gser);
+
 /**
 * Return a number indicating presence of Z and M coordinates.
 * 0 = None, 1 = M, 2 = Z, 3 = ZM
@@ -752,13 +763,21 @@ extern POINT2D getPoint2d(const POINTARRAY *pa, int n);
 extern int getPoint2d_p(const POINTARRAY *pa, int n, POINT2D *point);
 
 /**
-* Returns a pointer into the POINTARRAY serialized_ptlist, 
+* Returns a POINT2D pointer into the POINTARRAY serialized_ptlist, 
 * suitable for reading from. This is very high performance
 * and declared const because you aren't allowed to muck with the 
 * values, only read them.
 */
 extern const POINT2D* getPoint2d_cp(const POINTARRAY *pa, int n);
 
+/**
+* Returns a POINT3DZ pointer into the POINTARRAY serialized_ptlist, 
+* suitable for reading from. This is very high performance
+* and declared const because you aren't allowed to muck with the 
+* values, only read them.
+*/
+extern const POINT3DZ* getPoint3dz_cp(const POINTARRAY *pa, int n);
+
 /*
  * set point N to the given value
  * NOTE that the pointarray can be of any
@@ -1044,6 +1063,8 @@ extern double next_double_up(float d);
 	2D*/
 extern double distance2d_pt_pt(const POINT2D *p1, const POINT2D *p2);
 extern double distance2d_pt_seg(const POINT2D *p, const POINT2D *A, const POINT2D *B);
+extern double  distance2d_sqr_pt_pt(const POINT2D *p1, const POINT2D *p2);
+extern double  distance2d_sqr_pt_seg(const POINT2D *p, const POINT2D *A, const POINT2D *B);
 extern LWGEOM *lw_dist2d_distancepoint(LWGEOM *lw1, LWGEOM *lw2,int srid,int mode);
 extern LWGEOM *lw_dist2d_distanceline(LWGEOM *lw1, LWGEOM *lw2,int srid,int mode);
 extern double lwgeom_mindistance2d(LWGEOM *lw1, LWGEOM *lw2);
@@ -1075,6 +1096,7 @@ extern LWPOINT* lwcircstring_get_lwpoint(LWCIRCSTRING *circ, int where);
 
 extern double ptarray_length_2d(const POINTARRAY *pts);
 extern double ptarray_length(const POINTARRAY *pts);
+extern double ptarray_arc_length_2d(const POINTARRAY *pts);
 
 
 extern int pt_in_ring_2d(const POINT2D *p, const POINTARRAY *ring);
@@ -1820,7 +1842,6 @@ extern void lwfree(void *mem);
 /* Utilities */
 extern char *lwmessage_truncate(char *str, int startpos, int endpos, int maxlength, int truncdirection);
 
-
 /*******************************************************************************
  * SQLMM internal functions - TODO: Move into separate header files
  ******************************************************************************/
