@@ -1,6 +1,6 @@
 
 
--- $Id: legacy_minimal.sql.in.c 9735 2012-05-16 08:29:14Z robe $
+-- $Id: legacy_minimal.sql.in 11175 2013-03-18 17:20:18Z strk $
 -- Bare minimum Legacy functions --
 -- This file that contains what we have determined are
 -- the most common functions used by older apps
@@ -36,29 +36,29 @@
 -- Deprecation in 1.2.3
 CREATE OR REPLACE FUNCTION AsBinary(geometry)
 	RETURNS bytea
-	AS '$libdir/postgis-2.0','LWGEOM_asBinary'
+	AS '$libdir/postgis-2.1','LWGEOM_asBinary'
 	LANGUAGE 'c' IMMUTABLE STRICT;
 	
 -- Deprecation in 1.2.3
 CREATE OR REPLACE FUNCTION AsBinary(geometry,text)
 	RETURNS bytea
-	AS '$libdir/postgis-2.0','LWGEOM_asBinary'
+	AS '$libdir/postgis-2.1','LWGEOM_asBinary'
 	LANGUAGE 'c' IMMUTABLE STRICT;
 
 -- Deprecation in 1.2.3
 CREATE OR REPLACE FUNCTION AsText(geometry)
 	RETURNS TEXT
-	AS '$libdir/postgis-2.0','LWGEOM_asText'
+	AS '$libdir/postgis-2.1','LWGEOM_asText'
 	LANGUAGE 'c' IMMUTABLE STRICT;	
 
 -- Deprecation in 1.2.3
 CREATE OR REPLACE FUNCTION Estimated_Extent(text,text,text) RETURNS box2d AS
-	'$libdir/postgis-2.0', 'geometry_estimated_extent'
+	'$libdir/postgis-2.1', 'geometry_estimated_extent'
 	LANGUAGE 'c' IMMUTABLE STRICT SECURITY DEFINER;
 	
 -- Deprecation in 1.2.3
 CREATE OR REPLACE FUNCTION Estimated_Extent(text,text) RETURNS box2d AS
-	'$libdir/postgis-2.0', 'geometry_estimated_extent'
+	'$libdir/postgis-2.1', 'geometry_estimated_extent'
 	LANGUAGE 'c' IMMUTABLE STRICT SECURITY DEFINER;
 	
 -- Deprecation in 1.2.3
@@ -74,18 +74,35 @@ CREATE OR REPLACE FUNCTION GeomFromText(text)
 -- Deprecation in 1.2.3
 CREATE OR REPLACE FUNCTION ndims(geometry)
 	RETURNS smallint
-	AS '$libdir/postgis-2.0', 'LWGEOM_ndims'
+	AS '$libdir/postgis-2.1', 'LWGEOM_ndims'
 	LANGUAGE 'c' IMMUTABLE STRICT;
 	
 -- Deprecation in 1.2.3
 CREATE OR REPLACE FUNCTION SetSRID(geometry,int4)
 	RETURNS geometry
-	AS '$libdir/postgis-2.0','LWGEOM_set_srid'
+	AS '$libdir/postgis-2.1','LWGEOM_set_srid'
 	LANGUAGE 'c' IMMUTABLE STRICT;
 	
 -- Deprecation in 1.2.3
 CREATE OR REPLACE FUNCTION SRID(geometry)
 	RETURNS int4
-	AS '$libdir/postgis-2.0','LWGEOM_get_srid'
+	AS '$libdir/postgis-2.1','LWGEOM_get_srid'
 	LANGUAGE 'c' IMMUTABLE STRICT;
 	
+-- Deprecation in 1.5.0
+-- hack to allow unknown to cast to geometry
+-- so does not yield function is not unique
+CREATE OR REPLACE FUNCTION ST_AsBinary(text)
+	RETURNS bytea
+	AS 
+	$$ SELECT ST_AsBinary($1::geometry);$$
+	LANGUAGE 'sql' IMMUTABLE STRICT;
+	
+-- Deprecation in 1.5.0
+-- hack to allow unknown to cast to geometry
+-- so does not yield function is not unique
+CREATE OR REPLACE FUNCTION ST_AsText(bytea)
+	RETURNS text
+	AS 
+	$$ SELECT ST_AsText($1::geometry);$$
+	LANGUAGE 'sql' IMMUTABLE STRICT;
